@@ -14,7 +14,7 @@ use Module::Find;
 use Router::Simple;
 use Scalar::Util qw/weaken/;
 
-our $VERSION = '1.42';
+our $VERSION = '1.50';
 
 use constant {
 	BEFORE_DISPATCH    => 'before_dispatch',
@@ -143,6 +143,8 @@ sub conf {
 
 sub dump {
 	my $self = shift;
+	local $Data::Dumper::Indent = 1;
+	local $Data::Dumper::Terse  = 1;
 	Data::Dumper->Dump([@_]);
 }
 
@@ -201,9 +203,11 @@ sub dispatch {
 			$self->proctitle(sprintf "[Dwarf] %s::%s() (%s)", $controller, lc $self->method, $self->base_dir);
 
 			$self->handler->init($self);
+			
 			my $body = $self->handler->$method($self, @_);
-
 			$self->body($body);
+
+			$self->handler->did_dispatch($self, $body);
 		};
 		if ($@) {
 			my $error = $@;
@@ -391,7 +395,7 @@ sub find_method {
 	my ($self) = @_;
 	my $request_method = $self->method;
 	$request_method = lc $request_method if defined $request_method;
-	return unless $request_method =~ /^(get|post|put|delete|options)$/;
+	return unless $request_method =~ /^(get|post|put|delete|options|patch|trace|link|unlink)$/;
 	return sub {} if $request_method eq 'options'; # for preflight request (CORS)
 	return $self->handler->can($request_method)
 		|| $self->handler->can($self->request_handler_method);
