@@ -2,6 +2,7 @@ package Dwarf::Module::APIBase;
 use Dwarf::Pragma;
 use parent 'Dwarf::Module';
 use Dwarf::Validator;
+use Dwarf::Validator::Constraint;
 use HTTP::Date;
 
 use Dwarf::Accessor {
@@ -79,6 +80,7 @@ sub call_before_trigger {
 }
 
 sub will_dispatch {}
+sub did_dispatch {}
 
 sub validate {
 	my ($self, @rules) = @_;
@@ -94,6 +96,23 @@ sub validate {
 	}
 }
 
+sub validate_response {
+	my ($self, @rules) = @_;
+	return if $self->c->is_production;
+
+	eval {
+		$self->args(
+			{ @rules },
+			$self,
+			$self->c->response->body
+		);
+	};
+
+	if ($@) {
+		$self->c->error->ERROR($@);
+	}
+}
+
 # レンダリング前の共通処理
 sub will_render {
 	my ($self, $c, $data) = @_;
